/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: oi_wavelength.h,v 1.1 2003/07/29 12:52:02 jaffe Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jaffe 2003-07-24  written
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: oi_wavelength.h,v 1.1 2003/07/29 12:52:02 jaffe Exp $ */

#ifndef _OI_WAVELENGTH_TABLE_H
#define _OI_WAVELENGTH_TABLE_H
/*----------------------------------------------------------------------- */
/* Wavelength table FITS binary tables routines                                */
/*----------------------------------------------------------------------- */
#include "VLTItable.h"

typedef struct      /* table definition for oi_wavelength table */
{
  table_def *def;       /* basic table information */
  long   row;           /* last row (0-rel) read or written, -1=> none. */
  char   *insname;      /* instrument name */
  int    nWave;          /* number of wavelengths specified */
  int    wave_col;      /* Time column number (0-rel) */
  int    band_col;      /* Time column number (0-rel) */
} wavelength_table_def;

typedef struct      /* structure used for jaffe row */
{
  float    wave;     /* wavelength (meters) */
  float    band;     /* delta wavelength (meters) */
  table_row *raw;    /* generic table row */
} wavelength_table_row;

/* public functions */

/* wavelength_table_row functions */
  wavelength_table_row* make_wavelength_table_row(wavelength_table_def* table);
/*----------------------------------------------------------------------- */
/*   Make an wavelength_table_row structure                           */
/*   Inputs:                                                              */
/*      table     pointer to wavelength_table table structure         */
/*   Returns:                                                             */
/*      An wavelength_table_row structure pointer ; NULL => failure   */
/*      Data pointers set to generic structure values                     */
/*----------------------------------------------------------------------- */

void kill_wavelength_table_row (wavelength_table_row *row);
/*----------------------------------------------------------------------- */
/*   Delete an wavelength_table_row structure                         */
/*   Inputs:                                                              */
/*      row    pointer to the wavelength_table_row structure.         */
/*----------------------------------------------------------------------- */

/* wavelength_table functions */

wavelength_table_def* 
make_wavelength_table_def(fitsfile *fptr, int nWave, char *insname, int *ierr);
/*----------------------------------------------------------------------- */
/*   Make a new wavelength_table in an open FITS file                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      nWave     number of wavelength channels                           */
/*      insname   instrument/detector name                                */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      A wavelength_table_def pointer; NULL indicates failure        */
/*----------------------------------------------------------------------- */

wavelength_table_def* 
open_wavelength_table(fitsfile *fptr, int *ierr);
/*----------------------------------------------------------------------- */
/*   Open an existing wavelength_table in the active FITS file        */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      An wavelength_table_def pointer; NULL indicates failure       */
/*----------------------------------------------------------------------- */

int read_wavelength_table(fitsfile *fptr,  wavelength_table_def* table, 
			    wavelength_table_row *row, long row_number,
			    int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next row from an wavelength_table                       */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row_number which row (1-rel) in the table                         */   
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      row       pointer to an extant row structure                      */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int write_wavelength_table(fitsfile *fptr, wavelength_table_def *table, 
			     wavelength_table_row *row,  long row_number,
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Write  the next row to an wavelength_table                               */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row       pointer to an extant row structure                      */
/*      row_number which row (1-rel) in the table                         */
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int close_wavelength_table(fitsfile *fptr, wavelength_table_def* table, 
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Close an open wavelength_table, associated structures are        */
/*   destroyed                                                            */
/*   Note: this closes the full FITS file                                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

void kill_wavelength_table_def (wavelength_table_def* table);
/*----------------------------------------------------------------------- */
/*   Delete an wavelength_table structure                             */
/*   Inputs:                                                              */
/*      table     table definitions structure from open or create         */
/*----------------------------------------------------------------------- */

#endif /* end _OI_WAVELENGTH_TABLE_H */
/* */
